@@ -635,7 +635,7 @@ class CameraDevice(Protocol):
     has_object_detector: bool
     has_ptz: bool
 
-    on_started: Observable
+    on_connected: Observable
     on_light_switched: Observable
     on_motion_detected: Observable
     on_audio_detected: Observable
@@ -732,8 +732,6 @@ class CameraDevice(Protocol):
 DeviceManagerEventType = Literal[
     "cameraSelected",
     "cameraDeselected",
-    # "cameraAdded",
-    # "cameraRemoved",
     "cameraUpdated",
 ]
 
@@ -760,14 +758,6 @@ class DeviceManager(Protocol):
     def on(
         self, event: Literal["cameraDeselected"], listener: CameraDeselectedCallback
     ) -> "DeviceManager": ...
-    # @overload
-    # def on(
-    #     self, event: Literal["cameraAdded"], listener: CameraAddedCallback
-    # ) -> "DeviceManager": ...
-    # @overload
-    # def on(
-    #     self, event: Literal["cameraRemoved"], listener: CameraRemovedCallback
-    # ) -> "DeviceManager": ...
     @overload
     def on(
         self, event: Literal["cameraUpdated"], listener: CameraUpdatedCallback
@@ -781,14 +771,6 @@ class DeviceManager(Protocol):
     def once(
         self, event: Literal["cameraDeselected"], listener: CameraDeselectedCallback
     ) -> "DeviceManager": ...
-    # @overload
-    # def once(
-    #     self, event: Literal["cameraAdded"], listener: CameraAddedCallback
-    # ) -> "DeviceManager": ...
-    # @overload
-    # def once(
-    #     self, event: Literal["cameraRemoved"], listener: CameraRemovedCallback
-    # ) -> "DeviceManager": ...
     @overload
     def once(
         self, event: Literal["cameraUpdated"], listener: CameraUpdatedCallback
@@ -802,14 +784,6 @@ class DeviceManager(Protocol):
     def remove_listener(
         self, event: Literal["cameraDeselected"], listener: CameraDeselectedCallback
     ) -> "DeviceManager": ...
-    # @overload
-    # def remove_listener(
-    #     self, event: Literal["cameraAdded"], listener: CameraAddedCallback
-    # ) -> "DeviceManager": ...
-    # @overload
-    # def remove_listener(
-    #     self, event: Literal["cameraRemoved"], listener: CameraRemovedCallback
-    # ) -> "DeviceManager": ...
     @overload
     def remove_listener(
         self, event: Literal["cameraUpdated"], listener: CameraUpdatedCallback
